@@ -40,7 +40,7 @@ module FileUtils
   def indir( dir, *args )
     args.flatten!
     args.collect do |fn|
-      %r(\A[/\\]) === fn ? fn : FU.join(dir, fn)
+      fn[0,1] == '/' ? fn : FU.join(dir, fn)
     end
   end
 
